#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.1.0.0
visibility:           public
id:                   summoner-2.1.0.0-AxiNf1IKjWgHnBlMgVW2aM
key:                  summoner-2.1.0.0-AxiNf1IKjWgHnBlMgVW2aM
license:              MPL-2.0
copyright:            2018-2026 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  898986d343e4b638e098cc40c85b1c43
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.Golden
    Summoner.License Summoner.Mode Summoner.Project Summoner.Question
    Summoner.Settings Summoner.Source Summoner.Template
    Summoner.Template.Cabal Summoner.Template.Doc
    Summoner.Template.GitHub Summoner.Template.Haskell
    Summoner.Template.Script Summoner.Template.Stack Summoner.Text
    Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.1.0.0-AxiNf1IKjWgHnBlMgVW2aM
depends:
    base-4.18.2.1 relude-1.2.2.2-JSCN2Lg4Rt5IdikwT5fmWS
    colourista-0.1.0.2-LxcBgqLDHxC3wtO8PNV7oM directory-1.3.8.5
    filepath-1.4.300.1 generic-data-1.1.0.2-FZIZsHSWInFKOPoDq3wrx7
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    microaeson-0.1.0.3-LDG9UH7aDJdEBdskRYZXWH
    optparse-applicative-0.18.1.0-7VN2J9FD8HH2Bl1L5dRVhn
    process-1.6.19.0 shellmet-0.0.6.0-Kx0WoxwIHOuHLRzS12S2SC
    time-1.12.2 tomland-1.3.3.3-EowIJCguJdhHPCV66VIIgE
    validation-selective-0.2.0.0-3wpKbbErAr58Ur1ovfuRoD

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

